import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  max,
  min,
  line,
  curveBasis
} from 'd3';


//Set the dimensions of the canvas
csv("earthquakes.csv")
  .then(data => {
    data.forEach(d => {
      d.year = new Date(d.year);
      d['8.0+'] = +d['8.0+'];
      d['7_7.9'] = +d['7_7.9'];
      d['6_6.9'] = +d['6_6.9'];
      d['5_5.9'] = +d['5_5.9'];
      d['Estimated Deaths'] = +d['Estimated Deaths'];
    });


const margin = {top: 50, right: 50, bottom: 50, left: 50}
  , width = window.innerWidth - margin.left - margin.right 
  , height = window.innerHeight - margin.top - margin.bottom; 

const innerWidth = width -200;
const innerHeight = height - 200;

const xValue = d => d.year;
const xAxisLabel = 'Year';
  
const yValue1 = d => d['5_5.9'];
const yValue2 = d => d['6_6.9'];
const yValue3 = d => d['7_7.9'];
const yValue4 = d => d['8.0+'];
const yAxisLabel = 'Num of Earthquakes';
const rValue = d => d['Estimated Deaths'];

const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth-50]);
  
const yScale = scaleLinear()
    .domain([0, max(data,yValue1)])
    .range([innerHeight, 0])
    .nice();
  
 const rScale = d3.scaleLinear()
    .domain([min(data, rValue), max(data, rValue)])
    .range([5,20]) 
  
var ysqScale = d3.scaleSqrt()
    .domain([d3.min(data, function(d) {return Math.min(d["8.0+"], d["7_7.9"], d["6_6.9"], d["5_5.9"]);})
    , d3.max(data, function(d) {return Math.max(d["8.0+"], d["7_7.9"], d["6_6.9"], d["5_5.9"]);})])  
    .range([height-50, 50]); 

var ysqAxis = d3.axisLeft(ysqScale).ticks(10);
 
 
const xAxis = axisBottom(xScale)
    .tickPadding(15);
  
const yAxis = axisLeft(yScale)
    .tickPadding(10);

 const lineGenerator1 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(ysqScale(d["8.0+"])))
    .curve(d3.curveMonotoneX) 
  	;
  
  const lineGenerator2 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(ysqScale(d["7_7.9"])))
    .curve(curveBasis)
    ;
  
  const lineGenerator3 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(ysqScale(d["6_6.9"])))
    .curve(curveBasis)
    ;
  
  const lineGenerator4 = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(ysqScale(d["5_5.9"])))
    .curve(curveBasis)
    ;  
  
  
const	svg1 = select("#area1").append("svg")
		.attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
    .append("g")
    .attr("transform", "translate(" + margin.left + "," + margin.top + ")");
  
  const g1 = svg1.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  
  
  const yAxisG = svg1.append('g').append('g').call(yAxis)
   .attr('transform', `translate(${margin.left},${margin.top})`);
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -60)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g1.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
    
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
 
  
  g1.append('path')
      .attr('class', 'line1')
      .attr('d', lineGenerator1(data));

  g1.append('path')
    .attr('class', 'line2')
    .attr('d', lineGenerator2(data));
  
  g1.append('path')
    .attr('class', 'line3')
    .attr('d', lineGenerator3(data));
  
  g1.append('path')
    .attr('class', 'line4')
    .attr('d', lineGenerator4(data));
  
  g1.append('text')
      .attr('class', 'title')
      .attr('y', -10)
  		.attr('x',innerWidth/6)
      .text('Earthquake Statistics for 2000-2015');
  


	g1.append('rect')
  	.attr('y', innerHeight/10)
  	.attr('x',innerWidth-40)
		.attr("width", 40)
    .attr("height", 20)
  	.style("fill", '#FFC300')
  
  g1.append('text')
    .attr('y', innerHeight/7)
  	.attr('x',innerWidth+10)
    .text("5_5.9");  
  
  	g1.append('rect')
  	.attr('y', innerHeight/5)
  	.attr('x',innerWidth-40)
		.attr("width", 40)
    .attr("height", 20)
  	.style("fill", '#FF5733')
  
  g1.append('text')
    .attr('y', innerHeight/4)
  	.attr('x',innerWidth+10)
    .text("6_6.9");  
  
  g1.append('rect')
  	.attr('y', innerHeight/3.3)
  	.attr('x',innerWidth-40)
		.attr("width", 40)
    .attr("height", 20)
  	.style("fill", '#C70039')
  
  g1.append('text')
    .attr('y', innerHeight/2.9)
  	.attr('x',innerWidth+10)
    .text("7_7.9");  
  
   g1.append('rect')
  	.attr('y', innerHeight/2.5)
  	.attr('x',innerWidth-40)
		.attr("width", 40)
    .attr("height", 20)
  	.style("fill", '#900C3F')
  
  g1.append('text')
    .attr('y', innerHeight/2.2)
  	.attr('x',innerWidth+10)
    .text("8.0+");  
  
  g1.append('text')
    .attr('y', innerHeight+100)
  	.attr('x',innerWidth-900)
    .text("Figure 3a: Example line chart");  
 	var colors = ['#FFC300', '#FF5733', '#C70039', '#900C3F']
	var types = ["8.0+", "7_7.9", "6_6.9", "5_5.9"]
 
  g1.selectAll(".dot").data(data).enter().append("circle") 
        .attr("cx", d => xScale(d["year"]))
  			.attr("cy", d => yScale(d["5_5.9"]))
        .attr("r", d  => rScale(+d["Estimated Deaths"]))
        .attr("fill", '#FFC300')

g1.selectAll(".dot").data(data).enter().append("circle") 
        .attr("cx", d => xScale(d["year"]))
  			.attr("cy", d => yScale(d["6_6.9"]))
        .attr("r", d  => rScale(+d["Estimated Deaths"]))
        .attr("fill", '#FF5733')

  g1.selectAll(".triangle").data(data)
    		.enter()
    		.append("path")
    		.attr("class", "triangle")
        .attr("fill", '#FF5733')
  			.attr("class", "triangle")
    		.attr("d", d3.svg.symbol().type("triangle-up").size(10))
    		.attr("transform", function(d) { return "translate(" + xScale(d["year"]) + "," + yScale(d["7_7.9"]) + ")"});
    
  

  

 	
 
	
  
});
